summaryrefslogtreecommitdiff
path: root/common
diff options
context:
space:
mode:
authorMary Ruthven <mruthven@chromium.org>2021-11-19 09:34:02 -0600
committerCommit Bot <commit-bot@chromium.org>2021-11-19 21:33:05 +0000
commit6d5efa406b96158e8f519064f5e377f60147cdc3 (patch)
tree3101f02d1f11ab1e7557a4534085bb813c68a924 /common
parentfabb25e9ebaa3f44adcd6e369c24e54021a9299b (diff)
downloadchrome-ec-6d5efa406b96158e8f519064f5e377f60147cdc3.tar.gz
coil: replace non-inclusive terms with "placeholder"
BUG=b:173227629 TEST=make buildall -j Change-Id: I2b203dfe45416aa3b632f6f788d14264b08f44e0 Signed-off-by: Mary Ruthven <mruthven@chromium.org> Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/3293252 Reviewed-by: Vadim Sukhomlinov <sukhomlinov@chromium.org>
Diffstat (limited to 'common')
-rw-r--r--common/cmsg.c2
-rw-r--r--common/new_nvmem.c10
-rw-r--r--common/test_util.c6
3 files changed, 9 insertions, 9 deletions
diff --git a/common/cmsg.c b/common/cmsg.c
index af733e72ef..63560171df 100644
--- a/common/cmsg.c
+++ b/common/cmsg.c
@@ -33,7 +33,7 @@ struct console_packet {
/* Set if the sender had to discard packets due to buffer overflow. */
uint8_t overflow : 1;
- uint8_t dummy : 3;
+ uint8_t placeholder : 3;
/* Channel; values from enum console_channel */
uint8_t channel;
diff --git a/common/test_util.c b/common/test_util.c
index 2d2d3ba462..da0daa49c7 100644
--- a/common/test_util.c
+++ b/common/test_util.c
@@ -30,13 +30,13 @@ int __test_error_count;
/* Weak reference function as an entry point for unit test */
test_mockable void run_test(void) { }
-/* Default dummy test init */
+/* Default placeholder test init */
test_mockable void test_init(void) { }
-/* Default dummy before test */
+/* Default placeholder before test */
test_mockable void before_test(void) { }
-/* Default dummy after test */
+/* Default placeholder after test */
test_mockable void after_test(void) { }
#ifdef TEST_COVERAGE
diff --git a/common/new_nvmem.c b/common/new_nvmem.c
index 1be4d4b4b2..da6d5f4370 100644
--- a/common/new_nvmem.c
+++ b/common/new_nvmem.c
@@ -707,7 +707,7 @@ static enum ec_error_list set_first_page_header(void)
*/
static int container_is_valid(struct nn_container *ch)
{
- struct nn_container dummy_c;
+ struct nn_container placeholder_c;
uint32_t hash;
uint32_t preserved_hash;
uint8_t preserved_type;
@@ -723,9 +723,9 @@ static int container_is_valid(struct nn_container *ch)
ch->container_hash = preserved_hash;
ch->container_type = preserved_type;
- dummy_c.container_hash = hash;
+ placeholder_c.container_hash = hash;
- return dummy_c.container_hash == ch->container_hash;
+ return placeholder_c.container_hash == ch->container_hash;
}
static uint32_t aligned_container_size(const struct nn_container *ch)
@@ -1881,7 +1881,7 @@ static void restore_object(void *pad, size_t size)
* flash - it would never be reinstated even after TPM reinitializes.
*
* The reserved_bitmap array is a bitmap of all detected reserved objects,
* those not in the array are initialized to a dummy initial value.
*/
static enum ec_error_list verify_reserved(uint8_t *reserved_bitmap,
struct nn_container *ch)
@@ -3053,7 +3053,7 @@ int nvmem_erase_tpm_data_selective(const uint32_t *objs_to_erase)
/*
* Now fill up the current flash page with erased objects to make sure
* that it would be erased during next compaction. Use dummy key,
* value pairs as the erase objects.
*/
saved_list_index = controller_at.list_index;
@@ -1881,7 +1881,7 @@ static void restore_object(void *pad, size_t size)
*
* The reserved_bitmap array is a bitmap of all detected reserved objects,
- * those not in the array are initialized to a dummy initial value.
+ * those not in the array are initialized to a placeholder initial value.
*/
static enum ec_error_list verify_reserved(uint8_t *reserved_bitmap,
@@ -3053,7 +3053,7 @@ int nvmem_erase_tpm_data_selective(const uint32_t *objs_to_erase)
/*
* Now fill up the current flash page with erased objects to make sure
- * that it would be erased during next compaction. Use dummy key,
+ * that it would be erased during next compaction. Use placeholder key,
* value pairs as the erase objects.
*/